@@ -1,4 +1,4 @@
-#     Copyright 2016, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2017, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -28,10 +28,8 @@ from nuitka.nodes.AssignNodes import (
     StatementAssignmentVariable,
     StatementReleaseVariable
 )
-from nuitka.nodes.BuiltinIteratorNodes import (
-    ExpressionBuiltinIter1,
-    ExpressionBuiltinNext1
-)
+from nuitka.nodes.BuiltinIteratorNodes import ExpressionBuiltinIter1
+from nuitka.nodes.BuiltinNextNodes import ExpressionBuiltinNext1
 from nuitka.nodes.CodeObjectSpecs import CodeObjectSpec
 from nuitka.nodes.ConditionalNodes import StatementConditional
 from nuitka.nodes.ConstantRefNodes import makeConstantRefNode
@@ -61,7 +59,6 @@ from nuitka.nodes.ParameterSpecs import ParameterSpec
 from nuitka.nodes.ReturnNodes import StatementReturn
 from nuitka.nodes.StatementNodes import (
     StatementExpressionOnly,
-    StatementGeneratorEntry,
     StatementsSequence
 )
 from nuitka.nodes.YieldNodes import ExpressionYield
@@ -388,14 +385,6 @@ def _buildContractionBodyNode(provider, node, emit_class, start_value,
     statements.append(current_body)
     statements = mergeStatements(statements)
 
-    if emit_class is ExpressionYield:
-        statements.insert(
-            0,
-            StatementGeneratorEntry(
-                source_ref = source_ref
-            )
-        )
-
     release_statements = [
         StatementReleaseVariable(
             variable   = tmp_variable,
